@@ -1,8 +1,12 @@
 from .mlm import MLMTopicClassifier
 from .mnli import NLITopicClassifierWithMappingHead, NLITopicClassifier
 from .nsp import NSPTopicClassifier
+from .babeldomains import BabelDomainsClassifier
+from .wndomains import WNDomainsClassifier
 
 __all__ = ['NLITopicClassifierWithMappingHead',
            'NLITopicClassifier',
            'MLMTopicClassifier',
-           'NSPTopicClassifier']
+           'NSPTopicClassifier',
+           'BabelDomainsClassifier',
+           'WNDomainsClassifier']
