@@ -7,7 +7,7 @@ import torch
 
 def np_softmax(x, dim=-1):
     e = np.exp(x)
-    return e / np.sum(e, axis=-1, keepdims=True)
+    return e / np.sum(e, axis=dim, keepdims=True)
 
 
 class TopicClassifier(object):
